Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(497)

Unified Diff: third_party/WebKit/Source/modules/webaudio/OfflineAudioContext.h

Issue 2103043007: Rename AbstractAudioContext to BaseAudioContext (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Use ASSERT(isGraphOwner()) instead of DCHECK Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/webaudio/OfflineAudioContext.h
diff --git a/third_party/WebKit/Source/modules/webaudio/OfflineAudioContext.h b/third_party/WebKit/Source/modules/webaudio/OfflineAudioContext.h
index e347a644621ff2b9f326137b6594b3512bfe9ca9..a3051138ba5c8fe8db4a5952e767bd2e9a287211 100644
--- a/third_party/WebKit/Source/modules/webaudio/OfflineAudioContext.h
+++ b/third_party/WebKit/Source/modules/webaudio/OfflineAudioContext.h
@@ -26,7 +26,7 @@
#define OfflineAudioContext_h
#include "modules/ModulesExport.h"
-#include "modules/webaudio/AbstractAudioContext.h"
+#include "modules/webaudio/BaseAudioContext.h"
#include "wtf/HashMap.h"
namespace blink {
@@ -34,7 +34,7 @@ namespace blink {
class ExceptionState;
class OfflineAudioDestinationHandler;
-class MODULES_EXPORT OfflineAudioContext final : public AbstractAudioContext {
+class MODULES_EXPORT OfflineAudioContext final : public BaseAudioContext {
DEFINE_WRAPPERTYPEINFO();
public:
static OfflineAudioContext* create(ExecutionContext*, unsigned numberOfChannels, unsigned numberOfFrames, float sampleRate, ExceptionState&);
@@ -51,7 +51,7 @@ public:
ScriptPromise suspendContext(ScriptState*, double);
ScriptPromise resumeContext(ScriptState*) final;
// This is to implement the pure virtual method from AbstractAudioContext.
// CANNOT be called from an OfflineAudioContext.
ScriptPromise suspendContext(ScriptState*) final;
@@ -64,7 +64,7 @@ public:
// Fire completion event when the rendering is finished.
void fireCompletionEvent();
// This is same with the online version in AbstractAudioContext class except
// for returning a boolean value after checking the scheduled suspends.
bool handlePreOfflineRenderTasks();
@@ -51,7 +51,7 @@ public:
ScriptPromise suspendContext(ScriptState*, double);
ScriptPromise resumeContext(ScriptState*) final;
- // This is to implement the pure virtual method from AbstractAudioContext.
+ // This is to implement the pure virtual method from BaseAudioContext.
// CANNOT be called from an OfflineAudioContext.
ScriptPromise suspendContext(ScriptState*) final;
@@ -64,7 +64,7 @@ public:
// Fire completion event when the rendering is finished.
void fireCompletionEvent();
- // This is same with the online version in AbstractAudioContext class except
+ // This is same with the online version in BaseAudioContext class except
// for returning a boolean value after checking the scheduled suspends.
bool handlePreOfflineRenderTasks();

Powered by Google App Engine
This is Rietveld 408576698